@@ -1,7 +1,7 @@
-mod campaign;
+pub mod campaign;
 pub mod client;
 mod paginator;
-mod user;
+pub mod user;
 
 pub type Error = anyhow::Error;
 pub type Result<T> = std::result::Result<T, Error>;
