@@ -1,10 +1,13 @@
 use std::sync::Arc;
 
-use serde::Deserialize;
+use serde::{Deserialize, Serialize};
 
-use crate::{campaign::Campaign, client::{ClientInner, ClientResponse}};
+use crate::{
+    campaign::Campaign,
+    client::{ClientInner, ClientResponse},
+};
 
-#[derive(Deserialize, Debug)]
+#[derive(Serialize, Deserialize, Debug)]
 pub struct Avatar {
     pub alt: String,
     pub src: String,
@@ -12,7 +15,7 @@ pub struct Avatar {
     pub width: u64,
 }
 
-#[derive(Deserialize, Debug)]
+#[derive(Serialize, Deserialize, Debug)]
 pub struct Social {
     pub discord: Option<String>,
     pub youtube: Option<String>,
@@ -23,7 +26,7 @@ pub struct Social {
     pub facebook: Option<String>,
 }
 
-#[derive(Deserialize, Debug)]
+#[derive(Serialize, Deserialize, Debug)]
 pub struct User {
     pub id: u64,
     pub username: String,
@@ -36,7 +39,7 @@ pub struct User {
     pub social: Social,
 }
 
-#[derive(Deserialize, Debug)]
+#[derive(Serialize, Deserialize, Debug)]
 pub struct UserSummary {
     pub id: u64,
     pub username: String,
@@ -68,7 +71,12 @@ impl UserBuilder {
 
     pub async fn campaigns(&self) -> crate::Result<Vec<Campaign>> {
         let url = format!("/api/v3/users/{}/campaigns", &self.user_id);
-        let response = self.client.get(&url, None).await?.json::<ClientResponse<Vec<Campaign>>>().await?;
+        let response = self
+            .client
+            .get(&url, None)
+            .await?
+            .json::<ClientResponse<Vec<Campaign>>>()
+            .await?;
         Ok(response.data)
     }
 }
